@@ -43,14 +43,14 @@ from .type_defs import (
     EntitiesDetectionJobFilterTypeDef,
     EntityRecognizerFilterTypeDef,
     KeyPhrasesDetectionJobFilterTypeDef,
-    ListDocumentClassificationJobsResponseTypeDef,
-    ListDocumentClassifiersResponseTypeDef,
-    ListDominantLanguageDetectionJobsResponseTypeDef,
-    ListEntitiesDetectionJobsResponseTypeDef,
-    ListEntityRecognizersResponseTypeDef,
-    ListKeyPhrasesDetectionJobsResponseTypeDef,
-    ListSentimentDetectionJobsResponseTypeDef,
-    ListTopicsDetectionJobsResponseTypeDef,
+    ListDocumentClassificationJobsResponseResponseTypeDef,
+    ListDocumentClassifiersResponseResponseTypeDef,
+    ListDominantLanguageDetectionJobsResponseResponseTypeDef,
+    ListEntitiesDetectionJobsResponseResponseTypeDef,
+    ListEntityRecognizersResponseResponseTypeDef,
+    ListKeyPhrasesDetectionJobsResponseResponseTypeDef,
+    ListSentimentDetectionJobsResponseResponseTypeDef,
+    ListTopicsDetectionJobsResponseResponseTypeDef,
     PaginatorConfigTypeDef,
     SentimentDetectionJobFilterTypeDef,
     TopicsDetectionJobFilterTypeDef,
@@ -70,7 +70,7 @@ __all__ = (
 
 class ListDocumentClassificationJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassificationJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassificationJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listdocumentclassificationjobspaginator)
     """
 
@@ -79,16 +79,16 @@ class ListDocumentClassificationJobsPaginator(Boto3Paginator):
         *,
         Filter: "DocumentClassificationJobFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDocumentClassificationJobsResponseTypeDef]:
+    ) -> Iterator[ListDocumentClassificationJobsResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassificationJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassificationJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listdocumentclassificationjobspaginator)
         """
 
 
 class ListDocumentClassifiersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassifiers)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassifiers)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listdocumentclassifierspaginator)
     """
 
@@ -97,16 +97,16 @@ class ListDocumentClassifiersPaginator(Boto3Paginator):
         *,
         Filter: "DocumentClassifierFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDocumentClassifiersResponseTypeDef]:
+    ) -> Iterator[ListDocumentClassifiersResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassifiers.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassifiers.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listdocumentclassifierspaginator)
         """
 
 
 class ListDominantLanguageDetectionJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListDominantLanguageDetectionJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListDominantLanguageDetectionJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listdominantlanguagedetectionjobspaginator)
     """
 
@@ -115,16 +115,16 @@ class ListDominantLanguageDetectionJobsPaginator(Boto3Paginator):
         *,
         Filter: "DominantLanguageDetectionJobFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDominantLanguageDetectionJobsResponseTypeDef]:
+    ) -> Iterator[ListDominantLanguageDetectionJobsResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListDominantLanguageDetectionJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListDominantLanguageDetectionJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listdominantlanguagedetectionjobspaginator)
         """
 
 
 class ListEntitiesDetectionJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listentitiesdetectionjobspaginator)
     """
 
@@ -133,16 +133,16 @@ class ListEntitiesDetectionJobsPaginator(Boto3Paginator):
         *,
         Filter: "EntitiesDetectionJobFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListEntitiesDetectionJobsResponseTypeDef]:
+    ) -> Iterator[ListEntitiesDetectionJobsResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listentitiesdetectionjobspaginator)
         """
 
 
 class ListEntityRecognizersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListEntityRecognizers)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListEntityRecognizers)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listentityrecognizerspaginator)
     """
 
@@ -151,16 +151,16 @@ class ListEntityRecognizersPaginator(Boto3Paginator):
         *,
         Filter: "EntityRecognizerFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListEntityRecognizersResponseTypeDef]:
+    ) -> Iterator[ListEntityRecognizersResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListEntityRecognizers.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListEntityRecognizers.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listentityrecognizerspaginator)
         """
 
 
 class ListKeyPhrasesDetectionJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListKeyPhrasesDetectionJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListKeyPhrasesDetectionJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listkeyphrasesdetectionjobspaginator)
     """
 
@@ -169,16 +169,16 @@ class ListKeyPhrasesDetectionJobsPaginator(Boto3Paginator):
         *,
         Filter: "KeyPhrasesDetectionJobFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListKeyPhrasesDetectionJobsResponseTypeDef]:
+    ) -> Iterator[ListKeyPhrasesDetectionJobsResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListKeyPhrasesDetectionJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListKeyPhrasesDetectionJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listkeyphrasesdetectionjobspaginator)
         """
 
 
 class ListSentimentDetectionJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listsentimentdetectionjobspaginator)
     """
 
@@ -187,16 +187,16 @@ class ListSentimentDetectionJobsPaginator(Boto3Paginator):
         *,
         Filter: "SentimentDetectionJobFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListSentimentDetectionJobsResponseTypeDef]:
+    ) -> Iterator[ListSentimentDetectionJobsResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listsentimentdetectionjobspaginator)
         """
 
 
 class ListTopicsDetectionJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListTopicsDetectionJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListTopicsDetectionJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listtopicsdetectionjobspaginator)
     """
 
@@ -205,8 +205,8 @@ class ListTopicsDetectionJobsPaginator(Boto3Paginator):
         *,
         Filter: "TopicsDetectionJobFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListTopicsDetectionJobsResponseTypeDef]:
+    ) -> Iterator[ListTopicsDetectionJobsResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehend.html#Comprehend.Paginator.ListTopicsDetectionJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/comprehend.html#Comprehend.Paginator.ListTopicsDetectionJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators.html#listtopicsdetectionjobspaginator)
         """
